"
I model a member of a Brea site, usually a human.
"
Class {
	#name : #BreaMember,
	#superclass : #Object,
	#instVars : [
		'givenName',
		'familyName',
		'picture',
		'country',
		'tags',
		'email',
		'password',
		'webPresence',
		'organizations'
	],
	#category : #Brea
}

{ #category : #converting }
BreaMember >> asStonModified [
	"asSton is generated a core dumped now. This renaming is trying to solve that. Maybe
	in the offical release it will be solved"
	^ STON toStringPretty: self
]

{ #category : #accessing }
BreaMember >> country [
	^ country
]

{ #category : #accessing }
BreaMember >> country: anObject [
	country := anObject
]

{ #category : #public }
BreaMember >> countryTemplate [
	^ '{{#country}}
    <tr>
     <td class="mdl-data-table__cell--non-numeric"><b>Country</b></td>
     <td class="mdl-data-table__cell--non-numeric">{{.}}</td>
    </tr>
  {{/country}}' asMustacheTemplate value: self
]

{ #category : #helpers }
BreaMember >> createTestUser [
	^ self class new 
	givenName: 'Test';
	familyName: 'User';
	country: 'Neverland';
	memberOf: 'HackBo' withWebsite: 'http://hackbo.co/';
	memberOf: 'mutabiT' withWebsite: 'http://mutabit.com/';
	website: 'http://test.user';
	twitter: '@offrayLC';
	email: 'iam@test.user';
	tags: 'just, a lot, of words, separated, by commas'.
]

{ #category : #accessing }
BreaMember >> email [
	^ email
]

{ #category : #accessing }
BreaMember >> email: anEmailAddress [
	email := (SHA1 new hashMessage: anEmailAddress) hex
]

{ #category : #accessing }
BreaMember >> facebook [
	^ self webPresence facebook.
]

{ #category : #accessing }
BreaMember >> facebook: aProfileName [
	aProfileName = '' 
		ifTrue: [ self webPresence facebook: nil ]
		ifFalse: [ self webPresence facebook: aProfileName ]
]

{ #category : #public }
BreaMember >> facebookTemplate [
	^ '{{#facebook}}
    <tr>
      <td class="mdl-data-table__cell--non-numeric">
        <b>Facebook</b></td>
      <td class="mdl-data-table__cell--non-numeric">
        <a href="https://facebook.com/{{.}}">
          {{.}}</a></td>
    </tr>
  {{/facebook}}' asMustacheTemplate value: self
]

{ #category : #accessing }
BreaMember >> familyName [
	^ familyName
]

{ #category : #accessing }
BreaMember >> familyName: anObject [
	familyName := anObject
]

{ #category : #helpers }
BreaMember >> fullName [
	^ self givenName asLowercase, '-', self familyName asLowercase 
]

{ #category : #accessing }
BreaMember >> getGenericProfilePicture [
	"Other considered avatars where:
	'https://upload.wikimedia.org/wikipedia/commons/1/1e/Default-avatar.jpg'"
	self picture: 'https://www.jamf.com/jamf-nation/img/default-avatars/generic-user.png'.
	^ picture
]

{ #category : #accessing }
BreaMember >> givenName [
	^ givenName
]

{ #category : #accessing }
BreaMember >> givenName: anObject [
	givenName := anObject
]

{ #category : #public }
BreaMember >> head [
	^ '<head>', self headMeta, self headTitle, self headStyles,'</head>'
]

{ #category : #utility }
BreaMember >> headMeta [
	^ '<meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="description" content="A portfolio template that uses Material Design Lite.">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, minimum-scale=1.0">'
]

{ #category : #utility }
BreaMember >> headStyles [
	^ '
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Roboto:regular,bold,italic,thin,light,bolditalic,black,medium&amp;lang=en">
    <link rel="stylesheet" href="https://code.getmdl.io/1.3.0/material.grey-pink.min.css" />
	 <link rel="stylesheet" href="http://mutabit.com/repos.fossil/gig/doc/tip/styles.css" />
    <link rel="stylesheet" href="styles.css" />
    <link rel="stylesheet" href="https://fonts.googleapis.com/icon?family=Material+Icons">
	'
]

{ #category : #utility }
BreaMember >> headTitle [
	^ self headTitled: 'GIG: Network'
]

{ #category : #utility }
BreaMember >> headTitled: aString [
	^ '<title>', aString ,'</title>'
]

{ #category : #public }
BreaMember >> html [
	"I show the member profile as HTML"
	^ self head, self htmlOutput
]

{ #category : #public }
BreaMember >> htmlInput [
	"I capture data in a HTML Form and use it to create a new BreaMember"
	^ '
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="description" content="A portfolio template that uses Material Design Lite.">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, minimum-scale=1.0">
    <title>Add Member | GIG Network</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Roboto:regular,bold,italic,thin,light,bolditalic,black,medium&amp;lang=en">
    <link rel="stylesheet" href="https://code.getmdl.io/1.3.0/material.grey-pink.min.css" />
    <link rel="stylesheet" href="styles.css" />
    <link rel="stylesheet" href="https://fonts.googleapis.com/icon?family=Material+Icons">
</head>
<body>
    <div class="mdl-layout mdl-js-layout mdl-layout--fixed-header">
        <div class="mdl-layout__drawer mdl-layout--small-screen-only">
            <nav class="mdl-navigation mdl-typography--body-1-force-preferred-font">
                <a class="mdl-navigation__link is-active" href="index.html">Portfolio</a>
                <a class="mdl-navigation__link" href="blog.html">Blog</a>
                <a class="mdl-navigation__link" href="about.html">About</a>
                <a class="mdl-navigation__link" href="contact.html">Contact</a>
            </nav>
        </div>
        <main class="mdl-layout__content">
            <div class="mdl-grid portfolio-max-width portfolio-contact">
                <div class="mdl-cell mdl-cell--12-col mdl-card mdl-shadow--4dp">
                    <div class="mdl-card__title">
                        <h2 class="mdl-card__title-text">Add new member</h2>
                    </div>
                    <div class="mdl-card__supporting-text">
                    <p>
                      Fill out the form.
                      The fields preceded by [*] are obligatory.
                    </p>
     <form enctype="application/x-www-form-urlencoded" action="summit" method="POST" class="">
       <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
         <input class="mdl-textfield__input" pattern="[A-Z,a-z, ]*" type="text" name="givenName">
           <label class="mdl-textfield__label" for="givenName">[*]Given Name...</label>
           <span class="mdl-textfield__error">Letters and spaces only</span>
        </div>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
         <input class="mdl-textfield__input" pattern="[A-Z,a-z, ]*" type="text" name="familyName">
           <label class="mdl-textfield__label" for="familyName">[*]Family Name...</label>
           <span class="mdl-textfield__error">Letters and spaces only</span>
        </div><br>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
          <input class="mdl-textfield__input" type="text" name="email">
          <label class="mdl-textfield__label" for="email">[*]Email...</label>
        </div>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
         <input class="mdl-textfield__input" pattern="[A-Z,a-z, ]*" type="text" name="country">
           <label class="mdl-textfield__label" for="country">[*]Country...</label>
           <span class="mdl-textfield__error">Letters and spaces only</span>
        </div><br>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
         <input class="mdl-textfield__input" pattern="[A-Z,a-z, ]*" type="text" name="organizations">
           <label class="mdl-textfield__label" for="organizations">
             [*]Organization(s) (separated with commas)</label>
           <span class="mdl-textfield__error">Letters and spaces only</span>
        </div><br>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
          <input class="mdl-textfield__input" type="text" name="picture">
          <label class="mdl-textfield__label" for="website">Profile picture url...</label>
        </div>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
          <input class="mdl-textfield__input" type="text" name="website">
          <label class="mdl-textfield__label" for="website">Personal website...</label>
        </div><br>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
          <input class="mdl-textfield__input" type="text" name="twitter">
          <label class="mdl-textfield__label" for="twitter">Twitter...</label>
        </div>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
          <input class="mdl-textfield__input" type="text" name="facebook">
          <label class="mdl-textfield__label" for="facebook">Facebook...</label>
        </div><br>
        <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">
          <textarea class="mdl-textfield__input" type="text" rows="5" name="tags"></textarea>
          <label class="mdl-textfield__label" for="tags">Tags (separated with commas)...</label>
        </div>
        <p>
        <button class="mdl-button mdl-js-button mdl-button--raised mdl-js-ripple-effect  
            mdl-button--accent" type="submit" value="Submit">
           Submit
          </button>
        </p>
       </form>
      </div>
    </div>
  </div>
  <footer class="mdl-mini-footer">
  <div class="mdl-mini-footer__left-section">
      <div class="mdl-logo">Simple portfolio website</div>
   </div>
   <div class="mdl-mini-footer__right-section">
     <ul class="mdl-mini-footer__link-list">
       <li><a href="#">Help</a></li>
       <li><a href="#">Privacy & Terms</a></li>
     </ul>
   </div>
  </footer>
</main>
    </div>
    <script src="https://code.getmdl.io/1.3.0/material.min.js"></script>
</body>
</html>
'
]

{ #category : #public }
BreaMember >> htmlOutput [
	
	^ self htmlOutputTemplate asMustacheTemplate value: self 
]

{ #category : #public }
BreaMember >> htmlOutputTemplate [
	"I show the member profile as HTML"
	^ '<div class="mdl-grid portfolio-max-width">
	    <div class="mdl-cell mdl-card mdl-shadow--4dp portfolio-card">
        <div class="mdl-card__title">
          <h2 class="mdl-card__title-text">{{givenName}} {{familyName}}</h2>
        </div>
        <div class="mdl-card__media">
          <img class="article-image" 
            src="{{picture}}" 
            border="0" alt="">
        </div>
        <div class="mdl-card__supporting-text">
          <table class="mdl-data-table mdl-js-data-table">
            <tbody>
              <tr>
                <td class="mdl-data-table__cell--non-numeric"><b>Name</b></td>
                <td class="mdl-data-table__cell--non-numeric">{{givenName}} {{familyName}}</td>
              </tr>',
              self countryTemplate,
              self organizationsTemplate, 
              self websiteTemplate,
              self twitterTemplate,
              self facebookTemplate,
              self tagsTemplate,
              '
          </tbody>
        </table>
      </div>
      <div class="mdl-card__actions mdl-card--border">
        <a class="mdl-button mdl-button--colored mdl-js-button 
            mdl-js-ripple-effect mdl-button--accent" 
			  href="portfolio-example01.html">Read more</a>
      </div>
    </div>
   </div> 
	'
]

{ #category : #accessing }
BreaMember >> instagram [
	^ self webPresence instagram.
]

{ #category : #accessing }
BreaMember >> instagram: aProfileName [
	self webPresence instagram: aProfileName
]

{ #category : #accessing }
BreaMember >> memberOf: anOrgName [
	self organizations add: 
		(BreaOrganization new name: anOrgName)
]

{ #category : #accessing }
BreaMember >> memberOf: anOrgName withWebsite: aUrl [
	self organizations add: 
		(BreaOrganization new 
			name: anOrgName;
			website: aUrl)
]

{ #category : #accessing }
BreaMember >> organizations [
	^ organizations ifNil: [ organizations := OrderedCollection new ]
]

{ #category : #accessing }
BreaMember >> organizations: anOrgListOrName [
	anOrgListOrName splitOn: ',' do: [ :each | self memberOf: each ] 
]

{ #category : #public }
BreaMember >> organizationsTemplate [
	^ '
	<tr>
     <td class="mdl-data-table__cell--non-numeric"><b>Organization(s)</b></td>
     <td class="mdl-data-table__cell--non-numeric">
       {{#organizations}}
         <a href="{{website}}">{{name}}</a>
       {{/organizations}}
      </td>
    </tr>' asMustacheTemplate value: self
]

{ #category : #accessing }
BreaMember >> password [
	^ password
]

{ #category : #accessing }
BreaMember >> password: anObject [
	password := anObject
]

{ #category : #accessing }
BreaMember >> picture [
	^ picture ifNil: [ ^ self getGenericProfilePicture ]
]

{ #category : #accessing }
BreaMember >> picture: anImageFilePath [
	picture := anImageFilePath
]

{ #category : #helpers }
BreaMember >> renderTestUserAsHtml [
	^ self class new createTestUser html
]

{ #category : #'server handling' }
BreaMember >> storeInto: aFileDirectory [
	| folder file |
	folder := (aFileDirectory asFileReference / self fullName) ensureCreateDirectory.
	file := (folder / 'info.ston') ensureCreateFile.
	file writeStreamDo: [:stream |
		(STON writer on: stream)
			newLine: String crlf;	
			prettyPrint: true;
			nextPut: self]
]

{ #category : #accessing }
BreaMember >> tags [
	^ tags
]

{ #category : #accessing }
BreaMember >> tags: anObject [
	tags := anObject
]

{ #category : #public }
BreaMember >> tagsTemplate [
	^ '{{#tags}}
    <tr>
      <td colspan="2"; style="text-align:left">
        <b>Tags</b><br>
        {{.}}
       </td>
    </tr>
  {{/tags}}' asMustacheTemplate value: self
]

{ #category : #accessing }
BreaMember >> twitter [
	^ self webPresence twitter.
]

{ #category : #accessing }
BreaMember >> twitter: aProfileName [
	aProfileName = ''
		ifTrue: [ self webPresence twitter: nil ]
		ifFalse: [ self webPresence twitter: aProfileName ]
]

{ #category : #public }
BreaMember >> twitterTemplate [
	^ '{{#twitter}}
    <tr>
      <td class="mdl-data-table__cell--non-numeric">
        <b>Twitter</b></td>
      <td class="mdl-data-table__cell--non-numeric">
        <a href="https://twitter.com/{{.}}">
          {{.}}</a></td>
    </tr>
  {{/twitter}}' asMustacheTemplate value: self
]

{ #category : #accessing }
BreaMember >> webPresence [
	^ webPresence ifNil: [ webPresence := BreaWebPresence new ]
]

{ #category : #accessing }
BreaMember >> webPresence: anObject [
	webPresence := anObject
]

{ #category : #accessing }
BreaMember >> website [
	^ self webPresence website.
]

{ #category : #accessing }
BreaMember >> website: anUrl [
	self webPresence website: anUrl
]

{ #category : #public }
BreaMember >> websiteTemplate [
	^ '{{#website}}
    <tr>
      <td class="mdl-data-table__cell--non-numeric"><b>Website</b></td>
      <td class="mdl-data-table__cell--non-numeric">
         <a href="{{.}}">{{.}}</a>
      </td>
  {{/website}}' asMustacheTemplate value: self
]
